==> ddd_3.0.orig.tar.gz: ddd-3.0/ddd/file.h <==
// $Id: file.h,v 1.14 1998/06/14 11:40:05 zeller Exp $ -*- C++ -*-
// DDD file handling

// Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
// 
// This file is part of DDD.
// 
// DDD is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// DDD is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public
// License along with DDD -- see the file COPYING.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.cs.tu-bs.de/softech/ddd/',
// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.

#ifndef _DDD_file_h
#define _DDD_file_h

#ifdef __GNUG__
#pragma interface
#endif

#include <X11/Intrinsic.h>
#include "strclass.h"
#include "StringA.h"

// Open file, process, core, source ...
extern void gdbOpenFileCB     (Widget, XtPointer, XtPointer);
extern void gdbOpenRecentCB   (Widget, XtPointer, XtPointer);
extern void gdbOpenClassCB    (Widget, XtPointer, XtPointer);
extern void gdbOpenProcessCB  (Widget, XtPointer, XtPointer);
extern void gdbOpenCoreCB     (Widget, XtPointer, XtPointer);
extern void gdbOpenSourceCB   (Widget, XtPointer, XtPointer);
extern void gdbLookupSourceCB (Widget, XtPointer, XtPointer);

// Get all sources from GDB
void get_gdb_sources(StringArray& sources_list);

// Update sources list
void update_sources();

// When entering `cd', change path in file selection boxes
extern void process_cd(string pwd);


// Capture information on current program
struct ProgramInfo {
    string file;		// Filename of current debuggee
    string core;		// Current core file
    int    pid;			// PID of debuggee
    bool   attached;		// Flag: is GDB attached to process?
    bool   running;		// Flag: is program running?
    string state;		// Verbose state description

    ProgramInfo();		// Initialize
};

#endif // _DDD_file_h
// DON'T ADD ANYTHING BEHIND THIS #endif

==> ddd-3.1.6.tar.gz: ddd-3.1.6/ddd/file.h <==
// $Id: file.h,v 1.16 1998/11/24 09:54:43 zeller Exp $ -*- C++ -*-
// DDD file handling

// Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
// 
// This file is part of DDD.
// 
// DDD is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// DDD is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public
// License along with DDD -- see the file COPYING.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.cs.tu-bs.de/softech/ddd/',
// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.

#ifndef _DDD_file_h
#define _DDD_file_h

#ifdef __GNUG__
#pragma interface
#endif

#include <X11/Intrinsic.h>
#include "strclass.h"
#include "StringA.h"

// Open file, process, core, source ...
extern void gdbOpenFileCB     (Widget, XtPointer, XtPointer);
extern void gdbOpenRecentCB   (Widget, XtPointer, XtPointer);
extern void gdbOpenClassCB    (Widget, XtPointer, XtPointer);
extern void gdbOpenProcessCB  (Widget, XtPointer, XtPointer);
extern void gdbOpenCoreCB     (Widget, XtPointer, XtPointer);
extern void gdbOpenSourceCB   (Widget, XtPointer, XtPointer);
extern void gdbLookupSourceCB (Widget, XtPointer, XtPointer);

// Get all sources from GDB
void get_gdb_sources(StringArray& sources_list);

// Update sources list
void update_sources();

// When entering `cd', change path in file selection boxes
extern void process_cd(string pwd);

// Get the file name from the file selection box W
string get_file(Widget w, XtPointer, XtPointer call_data);

// Capture information on current program
struct ProgramInfo {
    string file;		// Filename of current debuggee
    string core;		// Current core file
    int    pid;			// PID of debuggee
    bool   attached;		// Flag: is GDB attached to process?
    bool   running;		// Flag: is program running?
    string state;		// Verbose state description

    ProgramInfo();		// Initialize

    // This should avoid link warnings on SGI
    // as reported by Mike Tosti <tosti@cinesite.com>
    ~ProgramInfo() {}
};

#endif // _DDD_file_h
// DON'T ADD ANYTHING BEHIND THIS #endif
